import { p as proxyCustomElement, H, h, e as Host } from './p-c3592601.js';
import { d as defaultConfig, a as defaultIconPack, c as useLanguage } from './p-9bcf0d04.js';
import { d as defaultGridSize } from './p-b13ddb7d.js';
import { R as Render } from './p-60fdbd75.js';
import { S as SyncWithStore } from './p-b661e73e.js';

const rtkSpotlightGridCss = ":host{line-height:initial;font-family:var(--rtk-font-family, sans-serif);font-feature-settings:normal;font-variation-settings:normal}p{margin:var(--rtk-space-0, 0px);padding:var(--rtk-space-0, 0px)}:host{display:flex;height:100%;width:100%}main{flex:1 1 0%}.grid-width-sm{width:25%}.grid-width-md{width:50%}.grid-width-lg{width:66.666667%}:host([size='sm']),:host([size='md']){flex-direction:column}:host([size='md']) aside{max-height:var(--rtk-space-96, 384px);width:100%;max-width:100%}:host([size='md']) .grid-width-sm{height:25%}:host([size='md']) .grid-width-md{height:50%}:host([size='md']) .grid-width-lg{height:66.666667%}:host([size='sm']) aside{max-height:var(--rtk-space-96, 384px);width:100%;max-width:100%}:host([size='sm']) .grid-width-sm,:host([size='sm']) .grid-width-md,:host([size='sm']) .grid-width-lg{height:50%}:host([size='xl']) .grid-width-sm,:host([size='xl']) .grid-width-md,:host([size='xl']) .grid-width-lg{width:400px}:host([layout='column']){flex-direction:column}:host([layout='column']) main{flex:4}:host([layout='column']) aside{flex:2;max-width:100%;width:100%}";
const RtkSpotlightGridStyle0 = rtkSpotlightGridCss;

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const RtkSpotlightGrid$1 = /*@__PURE__*/ proxyCustomElement(class RtkSpotlightGrid extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        /** Grid Layout */
        this.layout = 'row';
        /** Participants */
        this.participants = [];
        /** Pinned Participants */
        this.pinnedParticipants = [];
        /**
         * Aspect Ratio of participant tile
         *
         * Format: `width:height`
         */
        this.aspectRatio = '16:9';
        /** Gap between participant tiles */
        this.gap = 8;
        /** UI Config */
        this.config = defaultConfig;
        /** Icon Pack */
        this.iconPack = defaultIconPack;
        /** Language */
        this.t = useLanguage();
        /** Grid size */
        this.gridSize = defaultGridSize;
        this.getAdaptiveSize = (length) => {
            if (this.size === 'sm') {
                return 'sm';
            }
            if (length > 3) {
                return 'sm';
            }
            else {
                if (this.size === 'md') {
                    return 'sm';
                }
                return 'md';
            }
        };
    }
    render() {
        const defaults = {
            meeting: this.meeting,
            config: this.config,
            states: this.states,
            size: this.size,
            iconPack: this.iconPack,
            t: this.t,
        };
        const nonPinnedParticipants = this.participants.filter((p) => this.pinnedParticipants.some((pt) => pt.id != p.id));
        return (h(Host, { key: '78a47e090097d8c758b7e78678c60c66231559e4' }, h("main", { key: '405ea4039c11b49abe9b7636f94b966b2a02388f', part: "main" }, h(Render, { key: 'bff026528181c24c2c761aa354678cb61aa01169', element: "rtk-simple-grid", defaults: defaults, props: {
                part: 'main-grid',
                participants: this.pinnedParticipants,
                aspectRatio: this.aspectRatio,
                gap: this.gap,
                size: this.getAdaptiveSize(this.pinnedParticipants.length),
            } })), nonPinnedParticipants.length > 0 && (h("aside", { key: 'f2f77d8371fef0a83c5682d0dd7bf4d6c57ea69b', part: "aside", class: this.gridSize.spotlight ? `grid-width-${this.gridSize.spotlight}` : 'grid-width-md' }, h(Render, { key: 'ba9e91c14b812c650275c4ae99bd602fb0f16aa0', element: "rtk-simple-grid", defaults: defaults, props: {
                part: 'aside-grid',
                participants: nonPinnedParticipants,
                aspectRatio: this.aspectRatio,
                gap: this.gap,
                size: this.getAdaptiveSize(nonPinnedParticipants.length),
            } })))));
    }
    get host() { return this; }
    static get style() { return RtkSpotlightGridStyle0; }
}, [1, "rtk-spotlight-grid", {
        "layout": [513],
        "participants": [16],
        "pinnedParticipants": [16],
        "aspectRatio": [1, "aspect-ratio"],
        "gap": [2],
        "size": [513],
        "meeting": [16],
        "states": [16],
        "config": [16],
        "iconPack": [16],
        "t": [16],
        "gridSize": [16]
    }]);
__decorate([
    SyncWithStore()
], RtkSpotlightGrid$1.prototype, "size", void 0);
__decorate([
    SyncWithStore()
], RtkSpotlightGrid$1.prototype, "meeting", void 0);
__decorate([
    SyncWithStore()
], RtkSpotlightGrid$1.prototype, "states", void 0);
__decorate([
    SyncWithStore()
], RtkSpotlightGrid$1.prototype, "iconPack", void 0);
__decorate([
    SyncWithStore()
], RtkSpotlightGrid$1.prototype, "t", void 0);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["rtk-spotlight-grid"];
    components.forEach(tagName => { switch (tagName) {
        case "rtk-spotlight-grid":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, RtkSpotlightGrid$1);
            }
            break;
    } });
}
defineCustomElement$1();

const RtkSpotlightGrid = RtkSpotlightGrid$1;
const defineCustomElement = defineCustomElement$1;

export { RtkSpotlightGrid, defineCustomElement };
